/*
 * Database record class for DAAP sharing
 *
 * Copyright (C) 2008 W. Michael Petullo <mike@flyn.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <string.h>

#include "test-daap-record.h"

struct TestDAAPRecordPrivate {
	gint filesize;
	gint rating;
	const char *location;
	const char *title;
	const char *format;
	const char *album;
	const char *artist;
	gulong bitrate;
	gint32 firstseen;
	gint32 mtime;
	gint32 disc;
	const char *genre;
	gint32 duration;
	gint32 track;
	gint32 year;
	gint8 has_video;
};

const char *
test_daap_record_get_location (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->location;
}

const char *
test_daap_record_get_title (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->title;
}

const char *
test_daap_record_get_album (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->album;
}

const char *
test_daap_record_get_artist (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->artist;
}

gulong
test_daap_record_get_bitrate (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->bitrate;
}

gint32
test_daap_record_get_firstseen (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->firstseen;
}

gint32
test_daap_record_get_mtime (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->mtime;
}

gint32
test_daap_record_get_disc (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->disc;
}

gint32
test_daap_record_get_rating (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->rating;
}

const char *
test_daap_record_get_genre (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->genre;
}

const char *
test_daap_record_get_format (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->format;
}

gint32
test_daap_record_get_filesize (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->filesize;
}

gint32
test_daap_record_get_duration (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->duration;
}

gint32
test_daap_record_get_track (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->track;
}

gint32
test_daap_record_get_year (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->year;
}

gint8
test_daap_record_has_video (DAAPRecord *record)
{
	return TEST_DAAP_RECORD (record)->priv->has_video;
}

GInputStream *test_daap_record_read (DAAPRecord *record, GError **error)
{
	GFile *file;
	GInputStream *stream;

	file = g_file_new_for_uri (TEST_DAAP_RECORD (record)->priv->location);
	stream = G_INPUT_STREAM (g_file_read (file, NULL, error));

	g_object_unref (file);

	return stream;
}

static void
test_daap_record_init (TestDAAPRecord *record)
{
	record->priv = TEST_DAAP_RECORD_GET_PRIVATE (record);
}

static void
test_daap_record_class_init (TestDAAPRecordClass *klass)
{
	g_type_class_add_private (klass, sizeof (TestDAAPRecordPrivate));
}

static void
test_daap_record_interface_init (gpointer iface, gpointer data)
{
	DAAPRecordInterface *daap_record = iface;

	g_assert (G_TYPE_FROM_INTERFACE (daap_record) == TYPE_DAAP_RECORD);

	daap_record->get_location = test_daap_record_get_location;
	daap_record->get_title = test_daap_record_get_title;
	daap_record->get_format = test_daap_record_get_format;
	daap_record->get_filesize = test_daap_record_get_filesize;
	daap_record->get_rating = test_daap_record_get_rating;
	daap_record->get_album = test_daap_record_get_album;
	daap_record->get_artist = test_daap_record_get_artist;
	daap_record->get_bitrate = test_daap_record_get_bitrate;
	daap_record->get_firstseen = test_daap_record_get_firstseen;
	daap_record->get_mtime = test_daap_record_get_mtime;
	daap_record->get_disc = test_daap_record_get_disc;
	daap_record->get_genre = test_daap_record_get_genre;
	daap_record->get_duration = test_daap_record_get_duration;
	daap_record->get_track = test_daap_record_get_track;
	daap_record->get_year = test_daap_record_get_year;
	daap_record->has_video = test_daap_record_has_video;
	daap_record->read = test_daap_record_read;
}

G_DEFINE_TYPE_WITH_CODE (TestDAAPRecord, test_daap_record, G_TYPE_OBJECT, 
			G_IMPLEMENT_INTERFACE (TYPE_DAAP_RECORD,
					       test_daap_record_interface_init))

TestDAAPRecord *test_daap_record_new (void)
{
	gchar *ext;
	TestDAAPRecord *record;

	record = TEST_DAAP_RECORD (g_object_new (TYPE_TEST_DAAP_RECORD, NULL));

	record->priv->location = g_strdup_printf ("file://%s/media/test.mp3", g_get_current_dir ());

	record->priv->title = "FIXME";

	record->priv->album = "FIXME";

	record->priv->artist = "FIXME";

	record->priv->bitrate = 128;

	record->priv->firstseen = 1;

	record->priv->mtime = 1;

	record->priv->disc = 1;

	record->priv->genre = "Blues";

	ext = strrchr (test_daap_record_get_location (DAAP_RECORD (record)),
						      '.');
	if (ext == NULL) {
		ext = "mp3";
	} else {
		ext++;
	}
	record->priv->format = g_strdup (ext);

	record->priv->filesize = 33729;

	record->priv->duration = 60;

	record->priv->track = 1;

	record->priv->year = 2008;

	record->priv->has_video = 0;

	return record;
}
